==> haskell-crypto-api-0.13.2-8-i686.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-api.sh <==
#!/bin/sh
export PATH='/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-api
version: 0.13.2
id: crypto-api-0.13.2-BMG9I4cfxb91dOhyZw6iKb
key: crypto-api-0.13.2-BMG9I4cfxb91dOhyZw6iKb
license: BSD3
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
homepage: https://github.com/TomMD/crypto-api
synopsis: A generic interface for cryptographic operations
description:
    A generic interface for cryptographic operations (hashes, ciphers, randomness).
    Maintainers of hash and cipher implementations are
    encouraged to add instances for the classes defined
    in Crypto.Classes.  Crypto users are similarly
    encouraged to use the interfaces defined in the Classes
    module.
    Any concepts or functions of general use to more than
    one cryptographic algorithm (ex: padding) is within
    scope of this package.
category: Data, Cryptography
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>, Francisco Blas Izquierdo Riera (klondike)
exposed: True
exposed-modules:
    Crypto.Classes Crypto.Types Crypto.HMAC Crypto.Random
    Crypto.Padding Crypto.Modes Crypto.Util Crypto.Classes.Exceptions
hidden-modules: Crypto.CPoly
abi: ca3ab0b7b677309777160e9f4dc7fbbe
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-api-0.13.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-api-0.13.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/crypto-api-0.13.2
hs-libraries: HScrypto-api-0.13.2-BMG9I4cfxb91dOhyZw6iKb
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    cereal-0.5.4.0-1RWVeyNi1If1ir8gxayRPi
    entropy-0.3.7-54dsRvsNlllHvcIX99CGiD
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-crypto-api/html/crypto-api.haddock
haddock-html: /usr/share/doc/haskell-crypto-api/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-api-0.13.2-10-i686.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-api.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-api
version: 0.13.2
id: crypto-api-0.13.2-6TxhqiP90JlKM4uj7GWEuA
key: crypto-api-0.13.2-6TxhqiP90JlKM4uj7GWEuA
license: BSD3
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
homepage: https://github.com/TomMD/crypto-api
synopsis: A generic interface for cryptographic operations
description:
    A generic interface for cryptographic operations (hashes, ciphers, randomness).
    Maintainers of hash and cipher implementations are
    encouraged to add instances for the classes defined
    in Crypto.Classes.  Crypto users are similarly
    encouraged to use the interfaces defined in the Classes
    module.
    Any concepts or functions of general use to more than
    one cryptographic algorithm (ex: padding) is within
    scope of this package.
category: Data, Cryptography
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>, Francisco Blas Izquierdo Riera (klondike)
exposed: True
exposed-modules:
    Crypto.Classes Crypto.Types Crypto.HMAC Crypto.Random
    Crypto.Padding Crypto.Modes Crypto.Util Crypto.Classes.Exceptions
hidden-modules: Crypto.CPoly
abi: 8aeb75e00bcceb1c19e70fadd1e43042
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/crypto-api-0.13.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/crypto-api-0.13.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/crypto-api-0.13.2
hs-libraries: HScrypto-api-0.13.2-6TxhqiP90JlKM4uj7GWEuA
depends:
    base-4.9.1.0 bytestring-0.10.8.1
    cereal-0.5.4.0-KtX8p6mYm6IKYn6d7ncsjw
    entropy-0.3.8-14HIw40nRRY968j6AdY1H4
    tagged-0.8.5-DG0qxw3gXxx4NfDcDx4Iai transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-crypto-api/html/crypto-api.haddock
haddock-html: /usr/share/doc/haskell-crypto-api/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
